@@ -13,8 +13,6 @@ RECONSTRUCTION_MIN_POSE_QUALITY = None
 RECONSTRUCTION_MIN_POSE_PAIR_SCORE = None
 RECONSTRUCTION_MAX_POSE_PAIR_SCORE = 25.0
 RECONSTRUCTION_POSE_PAIR_SCORE_DISTANCE_METHOD = 'pixels'
-RECONSTRUCTION_POSE_PAIR_SCORE_PIXEL_DISTANCE_SCALE = 5.0
-RECONSTRUCTION_POSE_PAIR_SCORE_SUMMARY_METHOD = 'rms'
 RECONSTRUCTION_POSE_3D_GRAPH_INITIAL_EDGE_THRESHOLD = 2
 RECONSTRUCTION_POSE_3D_GRAPH_MAX_DISPERSION = 0.20
 RECONSTRUCTION_INCLUDE_TRACK_LABELS = False
